@@ -1,5 +1,7 @@
 #!/usr/bin/perl -w
 
+package main;
+
 use warnings;
 use strict;
 use CAM::PDF;
@@ -7,6 +9,8 @@ use Data::Dumper;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.05';
+
 my %opts = (
             verbose    => 0,
             help       => 0,
@@ -37,7 +41,7 @@ my $file = shift;
 my $pagenum = shift;
 my $fontname = shift;
 
-if ($pagenum !~ /^\d+$/ || $pagenum < 1)
+if ($pagenum !~ m/\A\d+\z/xms || $pagenum < 1)
 {
    die "The page number must be an integer greater than 0\n";
 }
@@ -58,13 +62,15 @@ if ($opts{verbose})
 
 __END__
 
+=for stopwords getpdffontobject.pl
+
 =head1 NAME
 
 getpdffontobject.pl - Print the PDF form field names
 
 =head1 SYNOPSIS
 
-getpdffontobject.pl [options] infile.pdf pagenum fontname
+ getpdffontobject.pl [options] infile.pdf pagenum fontname
 
  Options:
    -v --verbose        print diagnostic messages
@@ -73,11 +79,11 @@ getpdffontobject.pl [options] infile.pdf pagenum fontname
 
 =head1 DESCRIPTION
 
-Retrieves the font metadata from the PDF.  If --verbose is specified,
+Retrieves the font metadata from the PDF.  If C<--verbose> is specified,
 the memory representation is dumped to STDOUT.  Otherwise, the program
 silently returns success or emits a failure message to STDERR.
 
-The leading C</> on the fontname is optional.
+The leading C</> on the C<fontname> argument is optional.
 
 =head1 SEE ALSO
 
@@ -86,3 +92,5 @@ CAM::PDF
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
