@@ -1,11 +1,16 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Data::Dumper;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.05';
+
 my %opts = (
             decode     => 0,
             content    => 0,
@@ -14,15 +19,22 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("d|decode"   => \$opts{decode},
-           "c|content"  => \$opts{content},
-           "v|verbose"  => \$opts{verbose},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('d|decode'   => \$opts{decode},
+           'c|content'  => \$opts{content},
+           'v|verbose'  => \$opts{verbose},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 2)
 {
@@ -32,13 +44,12 @@ if (@ARGV < 2)
 my $file = shift;
 my $pagenum = shift;
 
-if ($pagenum !~ /^\d+$/ || $pagenum < 1)
+if ($pagenum !~ m/\A\d+\z/xms || $pagenum < 1)
 {
    die "The page number must be an integer greater than 0\n";
 }
 
-my $doc = CAM::PDF->new($file);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($file) || die "$CAM::PDF::errstr\n";
 
 my $page = $doc->getPage($pagenum);
 
@@ -51,23 +62,28 @@ if ($opts{content})
    $page = $doc->getValue($page->{Contents});
 }
 
-$doc->decodeAll(CAM::PDF::Node->new("dictionary",$page)) if ($opts{decode});
+if ($opts{decode})
+{
+   $doc->decodeAll(CAM::PDF::Node->new('dictionary', $page));
+}
 
 if ($opts{verbose})
 {
-   print Data::Dumper->Dump([$page], ["page"]);
+   print Data::Dumper->Dump([$page], ['page']);
 }
 
 
 __END__
 
+=for stopwords getpdfpageobject.pl
+
 =head1 NAME
 
 getpdfpageobject.pl - Print the PDF page metadata
 
 =head1 SYNOPSIS
 
-getpdfpageobject.pl [options] infile.pdf pagenum
+ getpdfpageobject.pl [options] infile.pdf pagenum
 
  Options:
    -d --decode         uncompress any elements
@@ -78,7 +94,7 @@ getpdfpageobject.pl [options] infile.pdf pagenum
 
 =head1 DESCRIPTION
 
-Retrieves the page metadata from the PDF.  If --verbose is specified,
+Retrieves the page metadata from the PDF.  If C<--verbose> is specified,
 the memory representation is dumped to STDOUT.  Otherwise, the program
 silently returns success or emits a failure message to STDERR.
 
@@ -86,10 +102,12 @@ silently returns success or emits a failure message to STDERR.
 
 CAM::PDF
 
-getpdfpage.pl
+F<getpdfpage.pl>
 
-setpdfpage.pl
+F<setpdfpage.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
