@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.05';
+
 my %opts = (
             verbose    => 0,
             decode     => 0,
@@ -13,24 +18,32 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("v|verbose"  => \$opts{verbose},
-           "d|decode"   => \$opts{decode},
-           "p|pass"     => \$opts{askforpass},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('v|verbose'  => \$opts{verbose},
+           'd|decode'   => \$opts{decode},
+           'p|pass'     => \$opts{askforpass},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 1)
 {
    pod2usage(1);
 }
 
-my $file = shift || "-";
-my $doc = CAM::PDF->new($file, "", "", $opts{askforpass});
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $file = shift || q{-};
+my $doc = CAM::PDF->new($file, q{}, q{},
+                        { prompt_for_password => $opts{askforpass} })
+    || die "$CAM::PDF::errstr\n";
 
 if ($opts{decode})
 {
@@ -47,13 +60,15 @@ if ($opts{verbose})
 
 __END__
 
+=for stopwords readpdf.pl
+
 =head1 NAME
 
 readpdf.pl - Read a PDF document
 
 =head1 SYNOPSIS
 
-readpdf.pl [options] file.pdf
+ readpdf.pl [options] file.pdf
 
  Options:
    -d --decode         uncompress internal PDF components
@@ -72,9 +87,10 @@ also be a way to validate a PDF document.
 
 CAM::PDF
 
-rewritepdf.pl
+F<rewritepdf.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
 
+=cut
