@@ -1,9 +1,14 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.05';
+
 my %opts = (
             count      => 0,
             verbose    => 0,
@@ -11,14 +16,22 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("c|count"      => \$opts{count},
-           "v|verbose"    => \$opts{verbose},
-           "h|help"       => \$opts{help},
-           "V|version"    => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('c|count'      => \$opts{count},
+           'v|verbose'    => \$opts{verbose},
+           'h|help'       => \$opts{help},
+           'V|version'    => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-require("CAM::PDF"),print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   require CAM::PDF;
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 1)
 {
@@ -26,16 +39,14 @@ if (@ARGV < 1)
 }
 
 my $infile = shift;
-my $outfile = shift || "-";
+my $outfile = shift || q{-};
 
-local *IN;
-local *OUT;
+open my $in_fh, '<', $infile
+    or die "Failed to read file $infile\n";
+my $content = join q{}, <$in_fh>;
+close $in_fh;
 
-open(IN, $infile) or die "Failed to read file $infile\n";
-my $content = join("", <IN>);
-close(IN);
-
-my @matches = ($content =~ /[\r\n]%%EOF *[\r\n]/sg);
+my @matches = ($content =~ m/ [\r\n]%%EOF *[\r\n] /gxms);
 my $revs = @matches;
 
 if ($opts{count})
@@ -52,35 +63,40 @@ elsif ($revs == 1)
 }
 else
 {
-   if ($outfile eq "-")
+   # Figure out line end character
+   $content =~ m/ (.)%%EOF.*?\z /xms
+       or die "Cannot find the end-of-file marker\n";
+   my $lineend = $1;
+   my $eof = $lineend.'%%EOF';
+
+   my $i = rindex $content, $eof;
+   my $j = rindex $content, $eof, $i-1;
+   $content = (substr $content, 0, $j) . $eof . $lineend;
+
+   if ($outfile eq q{-})
    {
-      *OUT = *STDOUT;
+      print STDOUT $content;
    }
    else
    {
-      open(OUT, ">$outfile") or die "Cannot write to $outfile\n";
+      open my $fh, '>', $outfile or die "Cannot write to $outfile\n";
+      print {$fh} $content;
+      close $fh;
    }
-
-   # Figure out line end character
-   $content =~ /(.)%%EOF.*?$/s;
-   my $lineend = $1;
-   
-   my $i = rindex($content, "$lineend%%EOF");
-   my $j = rindex($content, "$lineend%%EOF", $i-1);
-   print OUT substr($content, 0, $j);
-   print OUT $lineend . "%%EOF" . $lineend;
 }
 
 
 __END__
 
+=for stopwords revertpdf.pl
+
 =head1 NAME
 
 revertpdf.pl - Remove the last edits to a PDF document
 
 =head1 SYNOPSIS
 
-revertpdf.pl [options] infile.pdf [outfile.pdf]\n";
+ revertpdf.pl [options] infile.pdf [outfile.pdf]\n";
 
  Options:
    -c --count          just print the number of revisions and exits
@@ -99,7 +115,7 @@ version of the PDF.
 This program remove the last layer of edits from the PDF document.  If
 there is just one revision, we emit a message and abort.
 
-The --count option just prints the number of generations the document
+The C<--count> option just prints the number of generations the document
 has endured and applies no changes.
 
 =head1 SEE ALSO
@@ -109,3 +125,5 @@ CAM::PDF
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
