@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.05';
+
 my %opts = (
             decode      => 0,
             cleanse     => 0,
@@ -23,31 +28,31 @@ my %opts = (
             version     => 0,
 
             # temporary variables
-            looking     => '',
+            looking     => q{},
             state       => 0,
             otherargs   => [],
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("1|2|3|4|5|6|7|8|9" => sub {$opts{newversion} = "1".$_[0]}, 
-           "c|cleanse"     => \$opts{cleanse},
-           "d|decode"      => \$opts{decode},
-           "f|filter=s"    => \@{$opts{filters}},
-           "C|clearannots" => \$opts{clearannots},
-           "X|decrypt"     => \$opts{decrypt},
-           "p|pass"        => sub { @{$opts{pass}}=(); $opts{looking}="pass"; $opts{state}=2; $opts{newpass}=1; },
-           "P|prefs"       => sub { @{$opts{prefs}}=(); $opts{looking}="prefs"; $opts{state}=4; $opts{newprefs}=1; },
-           "v|verbose"     => \$opts{verbose},
-           "o|order"       => \$opts{order},
-           "h|help"        => \$opts{help},
-           "V|version"     => \$opts{version},
-           "<>"            => sub {
+Getopt::Long::Configure('bundling');
+GetOptions('1|2|3|4|5|6|7|8|9' => sub {$opts{newversion} = '1'.$_[0]}, 
+           'c|cleanse'     => \$opts{cleanse},
+           'd|decode'      => \$opts{decode},
+           'f|filter=s'    => \@{$opts{filters}},
+           'C|clearannots' => \$opts{clearannots},
+           'X|decrypt'     => \$opts{decrypt},
+           'p|pass'        => sub { @{$opts{pass}}=(); $opts{looking}='pass'; $opts{state}=2; $opts{newpass}=1; },
+           'P|prefs'       => sub { @{$opts{prefs}}=(); $opts{looking}='prefs'; $opts{state}=4; $opts{newprefs}=1; },
+           'v|verbose'     => \$opts{verbose},
+           'o|order'       => \$opts{order},
+           'h|help'        => \$opts{help},
+           'V|version'     => \$opts{version},
+           '<>'            => sub {
               if ($opts{looking})
               {
                  push @{$opts{$opts{looking}}}, $_[0];
                  if (--$opts{state} == 0)
                  {
-                    $opts{looking} = '';
+                    $opts{looking} = q{};
                  }
               }
               else
@@ -56,8 +61,15 @@ GetOptions("1|2|3|4|5|6|7|8|9" => sub {$opts{newversion} = "1".$_[0]},
               }
            },
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 @ARGV = @{$opts{otherargs}};
 
@@ -67,23 +79,28 @@ if (@ARGV < 1)
 }
 
 my $infile = shift;
-my $outfile = shift || "-";
+my $outfile = shift || q{-};
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 if (!$doc->canModify())
 {
    die "This PDF forbids modification\n";
 }
 
-$doc->{pdfversion} = $opts{newversion} if ($opts{newversion});
+if ($opts{newversion})
+{
+   $doc->{pdfversion} = $opts{newversion};
+}
 
 if ($opts{decode} || @{$opts{filters}} > 0)
 {
    foreach my $obj (keys %{$doc->{xref}})
    {
-      $doc->decodeObject($obj) if ($opts{decode});
+      if ($opts{decode})
+      {
+         $doc->decodeObject($obj);
+      }
       foreach my $filtername (@{$opts{filters}})
       {
          $doc->encodeObject($obj, $filtername);
@@ -93,12 +110,18 @@ if ($opts{decode} || @{$opts{filters}} > 0)
 if ($opts{newprefs} || $opts{newpass})
 {
    my @p = $doc->getPrefs();
-   $p[0] = $opts{pass}->[0] if ($opts{newpass});
-   $p[1] = $opts{pass}->[1] if ($opts{newpass});
-   $p[2] = $opts{prefs}->[0] if ($opts{newprefs});
-   $p[3] = $opts{prefs}->[1] if ($opts{newprefs});
-   $p[4] = $opts{prefs}->[2] if ($opts{newprefs});
-   $p[5] = $opts{prefs}->[3] if ($opts{newprefs});
+   if ($opts{newpass})
+   {
+      $p[0] = $opts{pass}->[0];
+      $p[1] = $opts{pass}->[1];
+   }
+   if ($opts{newprefs})
+   {
+      $p[2] = $opts{prefs}->[0];
+      $p[3] = $opts{prefs}->[1];
+      $p[4] = $opts{prefs}->[2];
+      $p[5] = $opts{prefs}->[3];
+   }
    $doc->setPrefs(@p);
 }
 if ($opts{decrypt})
@@ -113,21 +136,32 @@ if ($opts{decrypt})
    }
 }
 
-$doc->clearAnnotations() if ($opts{clearannots});
-$doc->cleanse() if ($opts{cleanse});
-$doc->preserveOrder() if ($opts{order});
+if ($opts{clearannots})
+{
+   $doc->clearAnnotations();
+}
+if ($opts{cleanse})
+{
+   $doc->cleanse();
+}
+if ($opts{order})
+{
+   $doc->preserveOrder();
+}
 $doc->cleanoutput($outfile);
 
 
 __END__
 
+=for stopwords rewritepdf.pl
+
 =head1 NAME
 
 rewritepdf.pl - Rebuild a PDF file
 
 =head1 SYNOPSIS
 
-rewritepdf.pl [options] infile.pdf [outfile.pdf]\n";
+ rewritepdf.pl [options] infile.pdf [outfile.pdf]\n";
 
  Options:
    -c --cleanse        seek and destroy unreferenced metadata in the document
@@ -147,13 +181,13 @@ rewritepdf.pl [options] infile.pdf [outfile.pdf]\n";
 
 Read and write a PDF document, and possibly modify it along the way.
 
-The --cleanse option might break some PDFs which use undocumented or
-poorly documented PDF features.  Namely, some PDFs implicitly store
-their FontDescriptor objects just before their Font objects, without
-explicitly referring to the former.  Cleansing removes the former,
-causing Acrobat Reader to choke.
+The C<--cleanse> option could possibly break some PDFs which use
+undocumented or poorly documented PDF features.  Namely, some PDFs
+implicitly store their C<FontDescriptor> objects just before their Font
+objects, without explicitly referring to the former.  Cleansing
+removes the former, causing Acrobat Reader to choke.
 
-We recommend that you avoid the --decode and --filter options, as
+We recommend that you avoid the C<--decode> and C<--filter> options, as
 we're not sure they work right any longer.
 
 =head1 SEE ALSO
@@ -163,3 +197,5 @@ CAM::PDF
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
